@@ -3,7 +3,7 @@ aidsEst <- function( priceNames, shareNames, totExpName,
       shifterNames = NULL, method = "LA:L", hom = TRUE, sym = TRUE,
       pxBase = 1,
       estMethod = ifelse( is.null( instNames ), "SUR", "3SLS" ),
-      ILmaxiter = 50, ILtol = 1e-5, alpha0 = 0, TX = FALSE, ... ) {
+      ILmaxiter = 50, ILtol = 1e-5, alpha0 = 0, restrict.regMat = FALSE, ... ) {
 
    if( length( priceNames ) != length( shareNames ) ) {
       stop( "arguments 'priceNames' and 'shareNames' must have the same length" )
@@ -86,27 +86,27 @@ aidsEst <- function( priceNames, shareNames, totExpName,
          sysData[[ paste( "s", i, sep = "" ) ]] <- data[[ shifterNames[ i ] ]]
       }
    }
-   restr <- aidsRestr( nGoods = nGoods, hom = hom, sym = sym, TX = TX, nShifter = nShifter )
+   restr <- aidsRestr( nGoods = nGoods, hom = hom, sym = sym, restrict.regMat = restrict.regMat, nShifter = nShifter )
       # restrictions for homogeneity and symmetry
    system <- aidsSystem( nGoods = nGoods, nShifter = nShifter ) # LA-AIDS equation system
    # estimate system
-   if( TX ) {
-      est <- systemfit( estMethod, system, data = sysData, TX = restr,
+   if( restrict.regMat ) {
+      est <- systemfit( system, estMethod, data = sysData, restrict.regMat = restr,
          inst = ivFormula, ... )
    } else {
-      est <- systemfit( estMethod, system, data = sysData, R.restr = restr,
+      est <- systemfit( system, estMethod, data = sysData, restrict.matrix = restr,
          inst = ivFormula, ... )
    }
    if( substr( method, 1, 2 ) == "LA" ) {
-      result$coef <- aidsCoef( est$b, nGoods = nGoods, nShifter = nShifter,
-         cov = est$bcov, priceNames = priceNames, shareNames = shareNames,
-         shifterNames = shifterNames, df = est$df )   # coefficients
+      result$coef <- aidsCoef( coef( est ), nGoods = nGoods, nShifter = nShifter,
+         cov = vcov( est ), priceNames = priceNames, shareNames = shareNames,
+         shifterNames = shifterNames, df = df.residual( est ) )   # coefficients
       result$wFitted <- aidsCalc( priceNames, totExpName, data = data,
          coef = result$coef, lnp = lnp )$shares   # estimated budget shares
       iter <- est$iter
    } else if( substr( method, 1, 2 ) %in% c( "MK", "IL" ) ) {
-      b       <- est$b      # coefficients
-      bd      <- est$b      # difference of coefficients between
+      b       <- coef( est )# coefficients
+      bd      <- b          # difference of coefficients between
                             # this and previous step
       iter    <- est$iter   # iterations of each SUR estimation
       ILiter <- 1          # iterations of IL Loop
@@ -117,17 +117,17 @@ aidsEst <- function( priceNames, shareNames, totExpName,
          sysData$lxtr <- log( data[[ totExpName ]] ) -
             aidsPx( "TL", priceNames, shareNames, data = data,
             alpha0 = alpha0,
-            coef = aidsCoef( est$b, nGoods = nGoods, nShifter = nShifter ) )
+            coef = aidsCoef( coef( est ), nGoods = nGoods, nShifter = nShifter ) )
             # real total expenditure using Translog price index
-         if( TX ) {
-            est <- systemfit( estMethod, system, data = sysData, TX = restr,
+         if( restrict.regMat ) {
+            est <- systemfit( system, estMethod, data = sysData, restrict.regMat = restr,
                inst = ivFormula, ... )    # estimate system
          } else {
-            est <- systemfit( estMethod, system, data = sysData, R.restr = restr,
+            est <- systemfit( system, estMethod, data = sysData, restrict.matrix = restr,
                inst = ivFormula, ... )    # estimate system
          }
          iter <- c( iter, est$iter ) # iterations of each estimation
-         b    <- est$b   # coefficients
+         b    <- coef( est ) # coefficients
          bd   <- b - bl  # difference between coefficients from this
                          # and previous step
       }
@@ -135,7 +135,7 @@ aidsEst <- function( priceNames, shareNames, totExpName,
       sysData$lxtr <- log( data[[ totExpName ]] ) -
          aidsPx( "TL", priceNames, data = data,
          alpha0 = alpha0,
-         coef = aidsCoef( est$b, nGoods = nGoods, nShifter = nShifter ) )
+         coef = aidsCoef( coef( est ), nGoods = nGoods, nShifter = nShifter ) )
       # calculating matrix G
       Gmat <- cbind( rep( 1, nObs ), sysData$lxtr )
       for( i in 1:( nGoods ) ) {
@@ -149,30 +149,30 @@ aidsEst <- function( priceNames, shareNames, totExpName,
       # testing matrix G
       if( FALSE ) {
          for( i in 1:( nGoods - 1 ) ) {
-            print( est$eq[[ i ]]$fitted - Gmat %*%
-               est$b[ ( ( i - 1 ) * ( nGoods + 2 ) + 1 ):( i * (nGoods + 2 ) ) ] )
+            print( fitted( est$eq[[ i ]] ) - Gmat %*%
+               coef( est )[ ( ( i - 1 ) * ( nGoods + 2 ) + 1 ):( i * (nGoods + 2 ) ) ] )
          }
       }
       # calculating matrix J
-      jacobian <- aidsJacobian( est$b, priceNames, totExpName, data = data,
+      jacobian <- aidsJacobian( coef( est ), priceNames, totExpName, data = data,
          shifterNames = shifterNames, alpha0 = alpha0 )
       if( hom ) {
-         TXmat <- aidsRestr( nGoods = nGoods, nShifter = nShifter,
-            hom = hom, sym = sym, TX = TRUE )
+         modRegMat <- aidsRestr( nGoods = nGoods, nShifter = nShifter,
+            hom = hom, sym = sym, restrict.regMat = TRUE )
       } else {
-         TXmat <- diag( ( nGoods - 1 ) * ( nGoods + 2 + nShifter ) )
+         modRegMat <- diag( ( nGoods - 1 ) * ( nGoods + 2 + nShifter ) )
       }
-      # Jmat <- t( TXmat ) %*% ( diag( nGoods - 1 ) %x% t( Gmat ) ) %*% jacobian
-      # JmatInv <- TXmat %*% solve( Jmat ) %*% t( TXmat )
-      # bcov <- JmatInv  %*% ( est$rcov %x% ( t( Gmat ) %*% Gmat ) ) %*%
+      # Jmat <- t( modRegMat ) %*% ( diag( nGoods - 1 ) %x% t( Gmat ) ) %*% jacobian
+      # JmatInv <- modRegMat %*% solve( Jmat ) %*% t( modRegMat )
+      # bcov <- JmatInv  %*% ( est$residCov %x% ( t( Gmat ) %*% Gmat ) ) %*%
       #    t( JmatInv )
-      Jmat <- crossprod( TXmat, ( diag( nGoods - 1 ) %x% t( Gmat ) ) ) %*% jacobian
-      JmatInv <- TXmat %*% solve( Jmat, t( TXmat ) )
-      bcov <- JmatInv  %*% ( est$rcov %x% crossprod( Gmat ) ) %*%
+      Jmat <- crossprod( modRegMat, ( diag( nGoods - 1 ) %x% t( Gmat ) ) ) %*% jacobian
+      JmatInv <- modRegMat %*% solve( Jmat, t( modRegMat ) )
+      bcov <- JmatInv  %*% ( est$residCov %x% crossprod( Gmat ) ) %*%
          t( JmatInv )
-      result$coef <- aidsCoef( est$b, nGoods = nGoods, nShifter = nShifter,
+      result$coef <- aidsCoef( coef( est ), nGoods = nGoods, nShifter = nShifter,
          cov = bcov, priceNames = priceNames, shareNames = shareNames,
-         shifterNames = shifterNames, df = est$df )  # coefficients
+         shifterNames = shifterNames, df = df.residual( est ) )  # coefficients
       result$coef$alpha0 <- alpha0
       result$wFitted <- aidsCalc( priceNames, totExpName, data = data,
          coef = result$coef, alpha0 = alpha0, px = "TL" )$shares
@@ -204,7 +204,7 @@ aidsEst <- function( priceNames, shareNames, totExpName,
    }
    result$r2 <- numeric( nGoods )
    for( i in 1:( nGoods - 1 ) ) {
-      result$r2[ i ] <- est$eq[[ i ]]$r2
+      result$r2[ i ] <- summary( est$eq[[ i ]] )$r.squared
    }
    result$r2[ nGoods ] <- rSquared( data[ sample, shareNames[ nGoods ] ],
       result$wResid[ sample, nGoods ] )
