@@ -1,4 +1,4 @@
-aidsSystem <- function( nGoods, LA = TRUE ) {
+aidsSystem <- function( nGoods, nShifter = 0, LA = TRUE ) {
   if( LA ) {
     system <- list()
     for(i in 1:( nGoods - 1 ) ) {
@@ -7,6 +7,12 @@ aidsSystem <- function( nGoods, LA = TRUE ) {
         system[[ i ]] <- paste( system[[ i ]], " + lp",
            as.character( j ), sep = "" )
       }
+      if( nShifter > 0 ) {
+         for( j in 1:nShifter ) {
+            system[[ i ]] <- paste( system[[ i ]], " + s",
+               as.character( j ), sep = "" )
+         }
+      }
       system[[ i ]] <- as.formula( system[[ i ]] )
     }
   }
